@@ -17,6 +17,7 @@ import epcsunspecdemo.utils
 import sunspec.core.client
 import twisted.internet.defer
 
+import epyqlib.busproxy
 import epyqlib.canneo
 import epyqlib.device
 import epyqlib.nv
@@ -395,7 +396,7 @@ class Device:
     canmatrix = attr.ib(default=None)
     neo = attr.ib(default=None)
     nvs = attr.ib(default=None)
-    bus = attr.ib(default=None)
+    bus: epyqlib.busproxy.BusProxy = attr.ib(default=None)
     cyclic_frames = attr.ib(default=attr.Factory(set))
     default_elevated_access_level = attr.ib(default=None)
     default_access_level_password = attr.ib(default=None)
@@ -446,16 +447,6 @@ class Device:
         if self.bus is not None:
             raise BusAlreadySetError()
 
-        # TODO: take the next step on this hack
-        if sys.platform == "win32":
-            import can.interfaces.pcan.basic
-
-            bus.bus.m_objPCANBasic.SetValue(
-                bus.bus.m_PcanHandle,
-                can.interfaces.pcan.basic.PCAN_BUSOFF_AUTORESET,
-                True,
-            )
-
         try:
             self.neo.set_bus(bus=bus)
             self.nvs.set_bus(bus=bus)
@@ -642,10 +633,11 @@ class Device:
         if sleep > 0:
             await epyqlib.utils.twisted.sleep(sleep)
 
-        end = time.monotonic() + timeout
-        while True:
+        start = time.monotonic()
+        end = start + timeout
+        for retry in itertools.count():
             self.bus.transmit = False
-            self.bus.reset()
+            self.bus.reconnect()
             await epyqlib.utils.twisted.sleep(0.1)
             self.bus.transmit = True
             try:
@@ -656,8 +648,11 @@ class Device:
                 epyqlib.twisted.nvs.RequestTimeoutError,
                 epyqlib.twisted.nvs.SendFailedError,
             ) as e:
-                if time.monotonic() > end:
-                    raise RestartTimeoutError() from e
+                now = time.monotonic()
+                if now > end:
+                    raise RestartTimeoutError(
+                        f"Failed on retry {retry} after {now - start} seconds"
+                    ) from e
                 continue
             else:
                 break
