@@ -141,13 +141,9 @@ class FilesView(UiBase):
 
         self.lbl_login_status: QLabel = self.ui.lbl_login_status
         self.btn_login: QPushButton = self.ui.login
-        self.btn_logout: QPushButton = self.ui.logout
 
         self.lbl_serial_number: QLabel = self.ui.lbl_serial_number
         self.serial_number: QLineEdit = self.ui.serial_number
-        self.serial_number_from_parameters: QPushButton = (
-            self.ui.serial_number_from_parameters
-        )
         self.inverter_error: QLabel = self.ui.lbl_inverter_error
 
         self.files_grid: QTreeWidget = self.ui.files_grid
@@ -171,11 +167,7 @@ class FilesView(UiBase):
 
         # Bind click events
         self.btn_login.clicked.connect(self._login_clicked)
-        self.btn_logout.clicked.connect(self._logout_clicked)
         self.serial_number.returnPressed.connect(self._serial_number_entered)
-        self.serial_number_from_parameters.clicked.connect(
-            self._serial_number_from_parameters_clicked
-        )
 
         self.files_grid.itemClicked.connect(self.controller.file_item_clicked)
 
@@ -364,14 +356,6 @@ class FilesView(UiBase):
     def _login_clicked(self):
         ensureDeferred(self.controller.login_clicked()).addErrback(open_error_dialog)
 
-    def _logout_clicked(self):
-        ensureDeferred(self.controller.logout_clicked()).addErrback(open_error_dialog)
-
-    def _serial_number_from_parameters_clicked(self):
-        ensureDeferred(
-            self.controller.serial_number_from_parameters_clicked()
-        ).addErrback(open_error_dialog)
-
     def _notes_changed(self):
         changed = self.controller.notes_modified(
             self.description.text(), self.notes.toPlainText()
@@ -416,8 +400,6 @@ class FilesView(UiBase):
             self._render_firmware_menu(menu_pos, item)
         elif parent is self.section_headers.params:
             self._render_param_file_menu(menu_pos, item)
-        elif parent is self.section_headers.pmvs:
-            self._render_pmvs_file_menu(menu_pos, item)
 
     def _render_firmware_menu(self, menu_pos: QPoint, item: QTreeWidgetItem):
         menu = QMenu(self.files_grid)
@@ -474,17 +456,6 @@ class FilesView(UiBase):
         elif action is save_as:
             ensureDeferred(self.controller.save_file_as_clicked(item))
 
-    def _render_pmvs_file_menu(self, menu_pos: QPoint, item: QTreeWidgetItem):
-        menu = QMenu(self.files_grid)
-        save_as = menu.addAction("Save file as...")
-
-        action = menu.exec(menu_pos)
-
-        if action is None:
-            pass
-        elif action is save_as:
-            ensureDeferred(self.controller.save_file_as_clicked(item))
-
     def _render_raw_log_menu(self, menu_pos: QPoint, item: QTreeWidgetItem):
         # item_hash = next(hash for hash, row in self.pending_log_rows.items() if row == item)
         cached = self.controller.is_file_cached_locally(item)
@@ -551,11 +522,10 @@ class FilesView(UiBase):
             message = f"Logged in as {username}. " + message
 
         self.lbl_login_status.setText(message)
-        self._show_login_bar_widgets(connected)
+        self._show_login_bar_widgets(True)
 
     def _show_login_bar_widgets(self, enabled: bool):
         self.btn_login.setHidden(enabled)
-        self.btn_logout.setHidden(not enabled)
 
         self.lbl_serial_number.setHidden(not enabled)
         self.serial_number.setHidden(not enabled)
